@@ -1,5 +1,7 @@
 from . import (
     api,
     auth,
+    metadata,
+    parsers,
     utils,
 )
\ No newline at end of file
