@@ -1,4 +1,5 @@
 from enum import Enum
+from functools import partial
 
 import requests
 
@@ -99,13 +100,12 @@ class CommonAPI(GenericAPI):
             'description': description,
             'severity': severity.to_string(),
         }
-        r = requests.post(
+        curried_request = partial(
+            requests.post,
             url=url,
             data=data,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
+        r = self.attempt_api_call(curried_request=curried_request)
 
         if r.status_code < ERROR_THRESHOLD:
             return r.json()
@@ -115,12 +115,12 @@ class CommonAPI(GenericAPI):
     def get_units(self):
         """Get list of QUDT units."""
         url = f"{self._base_url}/api/common/units/"
-        r = requests.get(
+        curried_request = partial(
+            requests.get,
             url=url,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
+        r = self.attempt_api_call(curried_request=curried_request)
+
         if r.status_code < ERROR_THRESHOLD:
             return r.json()
         else:
@@ -129,12 +129,12 @@ class CommonAPI(GenericAPI):
     def get_vocab(self):
         """Get AFRL vocabulary (materials properties, etc)."""
         url = f"{self._base_url}/api/common/afrl-vocab/"
-        r = requests.get(
+        curried_request = partial(
+            requests.get,
             url=url,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
+        r = self.attempt_api_call(curried_request=curried_request)
+
         if r.status_code < ERROR_THRESHOLD:
             return r.json()
         else:
