@@ -18,7 +18,7 @@ class SearchAPI(GenericAPI):
 
     Parameters
     ----------
-    auth : auth.Authorization
+    auth : hyperthought.auth Authentication class
         Authorization object used to get headers and cookies needed to call
         HyperThought endpoints.
     """
