@@ -559,7 +559,7 @@ class WorkflowAPI(GenericAPI):
 
     Parameters
     ----------
-    auth : auth.Authorization
+    auth : hyperthought.auth Authentication class
         Authorization object used to get headers and cookies needed to call
         HyperThought endpoints.
     """
